@@ -467,7 +467,7 @@
         internal_tx_id=internal_tx_id,
         check.names=FALSE, stringsAsFactors=FALSE)
     table <- unique(table)
-    table <- table[!is.na(table$gene_id), ]
+    table <- S4Vectors:::extract_data_frame_rows(table, !is.na(table$gene_id))
     ## Create the 'gene' table.
     sql <- c(
         "CREATE TABLE gene (\n",
@@ -604,8 +604,6 @@ makeTxDb <- function(transcripts, splicings,
     TxDb(conn)
 }
 
-makeTranscriptDb <- function(...) .Defunct("makeTxDb")
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### makeToyTxDb().
@@ -638,9 +636,7 @@ makeToyTxDb <- function(splicings, genes=NULL)
 
 ## helper to list mirbase.db miRBaseBuild values for species
 supportedMiRBaseBuildValues <- function(){
-  require(mirbase.db)
-  res <- toTable(mirbaseSPECIES)[,c("name","genome_assembly")]
-  res <- res[!(res$genome_assembly==""),]
-  rownames(res) <- NULL
-  res
+    loadNamespace("mirbase.db")
+    res <- toTable(mirbase.db::mirbaseSPECIES)[,c("name","genome_assembly")]
+    S4Vectors:::extract_data_frame_rows(res, res$genome_assembly != "")
 }
