@@ -5,7 +5,7 @@ BiocStyle::latex()
 library("GenomicFeatures")
 
 ## ----loadDb-----------------------------------------------------------------------------
-samplefile <- system.file("extdata", "UCSC_knownGene_sample.sqlite",
+samplefile <- system.file("extdata", "hg19_knownGene_sample.sqlite",
                           package="GenomicFeatures")
 txdb <- loadDb(samplefile)
 txdb
@@ -19,13 +19,13 @@ txdb
 head(seqlevels(txdb))
 
 ## ----seqlevels2-------------------------------------------------------------------------
-seqlevels(txdb, force=TRUE) <- c("chr1")
+seqlevels(txdb) <- "chr1"
 
 ## ----seqlevels3-------------------------------------------------------------------------
-txdb <- restoreSeqlevels(txdb)
+seqlevels(txdb) <- seqlevels0(txdb)
 
 ## ----seqlevels4-------------------------------------------------------------------------
-seqlevels(txdb, force=TRUE) <- c("chr15")
+seqlevels(txdb) <- "chr15"
 
 ## ----selectExample----------------------------------------------------------------------
 keys <- c("100033416", "100033417", "100033420")
@@ -43,7 +43,7 @@ GR <- transcripts(txdb)
 GR[1:3]
 
 ## ----transcripts2-----------------------------------------------------------------------
-GR <- transcripts(txdb, vals <- list(tx_chrom = "chr15", tx_strand = "+"))
+GR <- transcripts(txdb, filter=list(tx_chrom = "chr15", tx_strand = "+"))
 length(GR)
 unique(strand(GR))
 
@@ -77,35 +77,34 @@ length(threeUTRsByTranscript(txdb))
 
 ## ----extract----------------------------------------------------------------------------
 library(BSgenome.Hsapiens.UCSC.hg19)
-tx_seqs1 <- extractTranscriptsFromGenome(Hsapiens, 
-                                         TxDb.Hsapiens.UCSC.hg19.knownGene)
+tx_seqs1 <- extractTranscriptSeqs(Hsapiens, TxDb.Hsapiens.UCSC.hg19.knownGene,
+                                  use.names=TRUE)
 
 ## ----translate1-------------------------------------------------------------------------
 suppressWarnings(translate(tx_seqs1))
 
 ## ----betterTranslation------------------------------------------------------------------
-cds_seqs <- extractTranscriptsFromGenome(Hsapiens, cdsBy(txdb, by="tx"))
+cds_seqs <- extractTranscriptSeqs(Hsapiens,
+                                  cdsBy(txdb, by="tx", use.names=TRUE))
 translate(cds_seqs)
 
 ## ----supportedUCSCtables----------------------------------------------------------------
-supportedUCSCtables()[1:4, ]
+supportedUCSCtables(genome="mm9")
 
-## ----makeTranscriptDbFromUCSC, eval=FALSE-----------------------------------------------
-#  mm9KG <- makeTranscriptDbFromUCSC(genome = "mm9", tablename = "knownGene")
+## ----makeTxDbFromUCSC, eval=FALSE-------------------------------------------------------
+#  mm9KG_txdb <- makeTxDbFromUCSC(genome="mm9", tablename="knownGene")
 
 ## ----discoverChromNames-----------------------------------------------------------------
 head(getChromInfoFromUCSC("hg19"))
 
-## ----makeTranscriptDbFromBiomart, eval=FALSE--------------------------------------------
-#  mmusculusEnsembl <-
-#     makeTranscriptDbFromBiomart(biomart = "ensembl",
-#                                dataset = "mmusculus_gene_ensembl")
+## ----makeTxDbFromBiomart, eval=FALSE----------------------------------------------------
+#  mmusculusEnsembl <- makeTxDbFromBiomart(dataset="mmusculus_gene_ensembl")
 
-## ----saveFeatures 1, eval=FALSE---------------------------------------------------------
-#  saveDb(mm9KG, file="fileName.sqlite")
+## ----saveDb-1, eval=FALSE---------------------------------------------------------------
+#  saveDb(mm9KG_txdb, file="fileName.sqlite")
 
-## ----loadFeatures-1, eval=FALSE---------------------------------------------------------
-#  mm9KG <- loadDb("fileName.sqlite")
+## ----loadDb-1, eval=FALSE---------------------------------------------------------------
+#  mm9KG_txdb <- loadDb("fileName.sqlite")
 
 ## ----SessionInfo, echo=FALSE------------------------------------------------------------
 sessionInfo()
